setAudioSettings method
Calls native code to set the speaker and bluetooth settings. The native layer will then observe changes to audio state and apply these settings as needed.
Implementation
Future setAudioSettings(bool speakerphoneEnabled, bool bluetoothPreferred) {
throw UnimplementedError('setAudioSettings() has not been implemented.');
}